@@ -12,7 +12,7 @@
 #' This function computes and plots the average wickets taken by the bowler versus the
 #' number of overs bowled
 #' @usage
-#' bowlerWicketPlot(df, name)
+#' bowlerWicketPlot(df, name,staticIntv1=1)
 #'
 #' @param df
 #' Data frame
@@ -20,6 +20,9 @@
 #' @param name
 #' Name of bowler
 #'
+#' @param staticIntv1
+#' Static or interactive -staticIntv1 =1 (static plot) &  staticIntv1 =2 (interactive  plot)
+#'
 #' @return None
 #' @references
 #' \url{https://cricsheet.org/}\cr
@@ -43,15 +46,24 @@
 #'
 #' @export
 #'
-bowlerWicketPlot <- function(df,name){
+bowlerWicketPlot <- function(df,name,staticIntv1=1){
     overs = runs = maidens = meanRuns = wickets = bowler = meanWickets = NULL
+    ggplotly=NULL
      c <- summarise(group_by(df,overs),meanRuns=mean(runs),meanMaidens=mean(maidens),
                     meanWickets=mean(wickets))
 
      plot.title <- paste(name,"- Average wickets vs overs")
-     ggplot(c,aes(x=overs, y=meanWickets,fill=overs)) +
-         geom_bar(data=c,stat="identity" ) +
-         xlab("Overs") + ylab("Mean Wickets") +
-         ggtitle(bquote(atop(.(plot.title),
-                             atop(italic("Data source:http://cricsheet.org/"),""))))
+     if(staticIntv1 ==1){ #ggplot2
+         ggplot(c,aes(x=overs, y=meanWickets,fill=overs)) +
+             geom_bar(data=c,stat="identity" ) +
+             xlab("Overs") + ylab("Mean Wickets") +
+             ggtitle(bquote(atop(.(plot.title),
+                                 atop(italic("Data source:http://cricsheet.org/"),""))))
+     } else { #ggplotly
+         g <-ggplot(c,aes(x=overs, y=meanWickets,fill=overs)) +
+             geom_bar(data=c,stat="identity" ) +
+             xlab("Overs") + ylab("Mean Wickets") +
+             ggtitle(plot.title)
+         ggplotly(g)
+     }
 }
