@@ -67,6 +67,12 @@ convertAllYaml2RDataframesT20 <- function(sourceDir=".",targetDirMen=".",targetD
         # Load yaml file
         a <- yaml.load_file(pth)
 
+        # This is a temporary change.
+        # Removing elements of Players,Registry and balls per over from yaml file
+        a[[2]][[10]] <- NULL #Players
+        a[[2]][[10]] <- NULL #Registry
+        a[[2]][[1]] <- NULL  #balls per over
+
         # Cast as data frame for easy processing
         tryCatch(b <- as.data.frame(a),
                  error = function(e) {
